[−][src]Function sp_io::crypto::sr25519_verify
pub fn sr25519_verify(sig: &Signature, msg: &[u8], pub_key: &Public) -> bool
Verify sr25519 signature.
Returns true when the verification is either successful or batched.
If no batching verification extension registered, this will return the result
of verification immediately. If batching verification extension is registered,
caller should call crypto::finish_batch_verify to actualy check all submitted